Exception: StandardLedger::NotRebuildable

Inherits:
Error
  • Object
show all
Defined in:
lib/standard_ledger/errors.rb

Overview

Raised by ‘StandardLedger.rebuild!` when the projector does not implement `rebuild` and is therefore not replayable from the entry log. Delta-based projectors (e.g. `increment_counter`-flavored) typically raise this because they cannot be reconstructed without summing the full log.